# Coding conventions that aider MUST follow

- Only use comments when necessary, since they can become outdated. Instead, strive to make the code self-explanatory.
- When comments are used, they should add useful information that is not readily apparent from the code.
